@@ -62,6 +62,10 @@ location_changed(LocationGPSDevice *device, gps_state_t *gps_state) {
     gps_state->altitude = device->fix->altitude;
   else
     gps_state->altitude = NAN;
+
+  if(gps_state->cb) 
+    if(!gps_state->cb(gps_state->data))
+      gps_state->cb = NULL;
 }
 
 void gps_init(appdata_t *appdata) {
