@@ -154,6 +154,7 @@ cb_menu_about(GtkMenuItem *item, gpointer data) {
     "Andrew Chadwick <andrewc-osm2go@piffle.org>",
     "Marcus Bauer <marcus.bauer@gmail.com>",
     "John Stowers <john.stowers@gmail.com>",
+    "Rolf Bode-Meyer <robome@gmail.com>",
     NULL };
 
   const gchar *artists[] = {
@@ -323,10 +324,9 @@ cb_menu_undo_changes(GtkMenuItem *item, gpointer data) {
   if(!yes_no_f(GTK_WIDGET(appdata->window), NULL, 0, 0,
 	       _("Undo all changes?"), 
 	       _("Throw away all the changes you've not "
-		 "uploaded yet? This can't be undone.")))
+		 "uploaded yet? This cannot be undone.")))
     return;
 
-  banner_busy_start(appdata, 1, _("Redrawing"));
   map_clear(appdata, MAP_LAYER_OBJECTS_ONLY);
 
   osm_free(&appdata->icon, appdata->osm);
@@ -335,7 +335,6 @@ cb_menu_undo_changes(GtkMenuItem *item, gpointer data) {
   diff_remove(appdata->project);
   appdata->osm = osm_parse(appdata->project->path, appdata->project->osm);
   map_paint(appdata);
-  banner_busy_stop(appdata);  //"Redrawing"
 
   banner_show_info(appdata, _("Undo all changes"));
 }
@@ -1442,7 +1441,7 @@ static GtkWidget *icon_button(appdata_t *appdata, char *icon, GCallback cb,
   GtkWidget *but = gtk_button_new();
   gtk_button_set_image(GTK_BUTTON(but), 
 		       icon_widget_load(&appdata->icon, icon));
-  gtk_button_set_relief(GTK_BUTTON(but), GTK_RELIEF_NONE);
+  //  gtk_button_set_relief(GTK_BUTTON(but), GTK_RELIEF_NONE);
   hildon_gtk_widget_set_theme_size(but, 
   		(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH));
 
