@@ -1569,7 +1569,7 @@ static gboolean map_motion_notify_event(GtkWidget *widget,
 
   if(!appdata->osm) return FALSE;
 
-#ifdef USE_HILDON
+#if 0 // def USE_HILDON
   /* reduce update frequency on hildon to keep screen update fluid */
   static guint32 last_time = 0;
 
@@ -1577,6 +1577,9 @@ static gboolean map_motion_notify_event(GtkWidget *widget,
   last_time = event->time;
 #endif
 
+  if(gtk_events_pending())
+    return FALSE;
+
   if(!map->pen_down.is) 
     return FALSE;
 
