@@ -49,15 +49,6 @@ gboolean project_close(appdata_t *appdata);
 gboolean project_check_demo(GtkWidget *parent, project_t *project);
 void project_wizard(appdata_t *appdata);
 
-#ifdef USE_HILDON
-#define POS_PARM  ,dbus_mm_pos_t *mmpos, osso_context_t *osso_context
-#else
-#define POS_PARM
-#endif
-
-gboolean project_edit(GtkWidget *parent, settings_t *settings,
-		      project_t *project POS_PARM);
-
 void project_free(project_t *project);
 
 #endif // PROJECT_H
